import { ElMessage } from 'element-plus';
import {
  markerClassTemplate,
  exportUserByExam,
  exportUserBySubject,
  exportUser,
  bindStudentTemplate,
  headerInspectorTemplate,
} from '@/api/user';
import useLoading from '@/hooks/loading';

import { downloadByApi } from './download';

const { loading, setLoading } = useLoading();

const downloadConfig = {
  // 评卷员班级导入模板下载
  markerClassTemplate,
  // 按考试导出用户
  exportUserByExam,
  // 按考试导出科目分表用户
  exportUserBySubject,
  // 导出用户
  exportUser,
  // 绑定考生导入模板下载
  bindStudentTemplate,
  // 科组长-复核员导入模板下载
  headerInspectorTemplate,
};

type DownloadType = keyof typeof downloadConfig;

export async function downloadExport(
  type: DownloadType,
  params?: Record<string, any>
) {
  if (loading.value) return;

  if (!downloadConfig[type]) {
    ElMessage.error('下载类型错误！');
    return;
  }

  setLoading(true);
  const res = await downloadByApi(() => downloadConfig[type](params)).catch(
    (e) => {
      ElMessage.error(e || '下载失败，请重新尝试！');
    }
  );
  setLoading(false);
  if (!res) return;
  ElMessage.success('下载成功！');
}
